@@ -125,6 +125,10 @@ class JsonSchemaObject(BaseModel):
             return None
         return values
 
+    @property
+    def has_default(self) -> bool:
+        return 'default' in self.__fields_set__
+
 
 JsonSchemaObject.update_forward_refs()
 
@@ -149,6 +153,8 @@ class JsonSchemaParser(Parser):
         strip_default_none: bool = False,
         aliases: Optional[Mapping[str, str]] = None,
         allow_population_by_field_name: bool = False,
+        file_path: Optional[Path] = None,
+        use_default_on_required_field: bool = False,
     ):
         super().__init__(
             data_model_type,
@@ -167,6 +173,8 @@ class JsonSchemaParser(Parser):
             strip_default_none,
             aliases,
             allow_population_by_field_name,
+            file_path,
+            use_default_on_required_field,
         )
 
         self.remote_object_cache: Dict[str, Dict[str, Any]] = {}
@@ -354,16 +362,23 @@ class JsonSchemaParser(Parser):
                         [*path, field_name], field_name, class_name=True
                     ).name
 
-                    # TODO: supports other types
+                    # TODO: supports other type
                     if field.additionalProperties.is_array:
-                        parse_method = self.parse_array
+                        additional_properties_type = self.parse_array(
+                            field_class_name,
+                            field.additionalProperties,
+                            [*path, field_name],
+                        ).name
                     else:
-                        parse_method = self.parse_object
-                    additional_properties_type = parse_method(
-                        field_class_name,
-                        field.additionalProperties,
-                        [*path, field_name],
-                    ).name
+                        additional_properties_type = self.parse_object(
+                            field_class_name,
+                            field.additionalProperties,
+                            [*path, field_name],
+                            additional_properties=None
+                            if field.additionalProperties.ref
+                            or field.additionalProperties.is_object
+                            else field,
+                        ).name
 
                     field_types = [
                         self.data_type(
@@ -389,7 +404,10 @@ class JsonSchemaParser(Parser):
                 field_types = self.get_data_type(field)
                 if self.field_constraints:
                     constraints = field.dict()
-            required: bool = original_field_name in requires
+            if self.use_default_on_required_field and field.has_default:
+                required: bool = False
+            else:
+                required = original_field_name in requires
             fields.append(
                 self.data_model_field_type(
                     name=field_name,
@@ -415,13 +433,14 @@ class JsonSchemaParser(Parser):
         path: List[str],
         singular_name: bool = False,
         unique: bool = False,
+        additional_properties: Optional[JsonSchemaObject] = None,
     ) -> DataModel:
         class_name = self.model_resolver.add(
             path, name, class_name=True, singular_name=singular_name, unique=unique
         ).name
         fields = self.parse_object_fields(obj, path)
         self.set_title(class_name, obj)
-        self.set_additional_properties(class_name, obj)
+        self.set_additional_properties(class_name, additional_properties or obj)
         data_model_type = self.data_model_type(
             class_name,
             fields=fields,
@@ -488,7 +507,6 @@ class JsonSchemaParser(Parser):
                 item_obj_data_types.extend(array_field.data_types)
             else:
                 item_obj_data_types.extend(self.get_data_type(item))
-
         field = self.data_model_field_type(
             data_types=item_obj_data_types,
             example=obj.example,
@@ -496,7 +514,8 @@ class JsonSchemaParser(Parser):
             default=obj.default,
             description=obj.description,
             title=obj.title,
-            required=True,
+            required=not obj.nullable
+            and not (obj.has_default and self.use_default_on_required_field),
             is_list=True,
             is_union=is_union,
         )
@@ -548,7 +567,8 @@ class JsonSchemaParser(Parser):
                     example=obj.example,
                     examples=obj.examples,
                     default=obj.default,
-                    required=not obj.nullable,
+                    required=not obj.nullable
+                    and not (obj.has_default and self.use_default_on_required_field),
                 )
             ],
             custom_base_class=self.base_class,
@@ -635,9 +655,14 @@ class JsonSchemaParser(Parser):
                                 ref_body = yaml.safe_load(f)
                             self.remote_object_cache[relative_path] = ref_body
                     object_paths = object_path.split('/')
-                    models = get_model_by_path(ref_body, object_paths)
+                    if object_path:
+                        models = get_model_by_path(ref_body, object_paths)
+                        model_name = object_paths[-1]
+                    else:
+                        models = ref_body
+                        model_name = Path(object_path).stem
                     self.parse_raw_obj(
-                        object_paths[-1], models, [str(full_path), '#', *object_paths],
+                        model_name, models, [str(full_path), '#', *object_paths],
                     )
                     self.model_resolver.add_ref(obj.ref).loaded = True
 
